@@ -21,6 +21,14 @@
 #ifndef CGAL_POLYTOPE_DISTANCE_D_H
 #define CGAL_POLYTOPE_DISTANCE_D_H
 
+#include <CGAL/license/Polytope_distance_d.h>
+
+
+#ifdef _MSC_VER
+# pragma warning(push)
+# pragma warning(disable: 4244) // conversion warning in Boost iterator_adaptor
+#endif
+
 // includes
 // --------
 #include <CGAL/Optimisation/basic.h>
@@ -928,6 +936,10 @@ operator << ( std::ostream& os,
 
 } //namespace CGAL
 
+#ifdef _MSC_VER
+# pragma warning(pop)
+#endif
+
 #endif // CGAL_POLYTOPE_DISTANCE_D_H
 
 // ===== EOF ==================================================================
